# A Keyed Data Type Role for Perl 5
package Data::Object::Role::Keyed;

use 5.010;
use Moo::Role;

our $VERSION = '0.12'; # VERSION

requires 'invert';

1;
